@@ -22,7 +22,8 @@ class Synapse(ABC):
             self.connection = self.raw_request.connection
             self.request = self.__set_request()
         except Exception as e:
-            err_msg = 'Failed to execute request {}'.format(raw_request)
+            err_msg = 'Failed to execute request {}'.format(raw_request.body)
+            self.logger.error(err_msg)
             self.init_error = ErrorResponse(message=err_msg, status_code=400, detail=str(e))
 
     def __set_request(self):
@@ -121,10 +122,12 @@ class Synapse(ABC):
                 raise Exception('Invalid synapse request {}'.format(self.request_type))
 
         except SyncariException as e:
+            err_msg = 'Failed to execute request {}'.format(self.request_type)
             response = e.error_response
             
         except Exception as e:
             err_msg = 'Failed to execute request {}'.format(self.request_type)
+            self.logger.error(err_msg + " due to " + str(e))
             response = ErrorResponse(message=err_msg, status_code=400, detail=str(e))
 
         if (isinstance(response, list)):
@@ -163,41 +166,41 @@ class Synapse(ABC):
         return SyncariLogger.get_logger(f"{self.name}")
 
     @abstractmethod
-    def synapse_info(self):
+    def synapse_info(self) -> SynapseInfo:
         pass
 
     @abstractmethod
-    def test(self, connection: Connection):
+    def test(self, connection: Connection) -> Connection:
         pass
 
     @abstractmethod
-    def describe(self, desc_request: DescribeRequest):
+    def describe(self, desc_request: DescribeRequest) -> List[Schema]:
         pass
 
     @abstractmethod
-    def read(self, sync_request: SyncRequest):
+    def read(self, sync_request: SyncRequest) -> ReadResponse:
         pass
 
     @abstractmethod
-    def get_by_id(self, sync_request: SyncRequest):
+    def get_by_id(self, sync_request: SyncRequest) -> List[Record]:
         pass
 
     @abstractmethod
-    def create(self, sync_request: SyncRequest):
+    def create(self, sync_request: SyncRequest) -> List[Result]:
         pass
 
     @abstractmethod
-    def update(self, sync_request: SyncRequest):
+    def update(self, sync_request: SyncRequest) -> List[Result]:
         pass
 
     @abstractmethod
-    def delete(self, sync_request: SyncRequest):
+    def delete(self, sync_request: SyncRequest) -> List[Result]:
         pass
 
     @abstractmethod
-    def extract_webhook_identifier(self, webhook_request: WebhookRequest):
+    def extract_webhook_identifier(self, webhook_request: WebhookRequest) -> str:
         pass
 
     @abstractmethod
-    def process_webhook(self, webhook_request: WebhookRequest):
+    def process_webhook(self, webhook_request: WebhookRequest) -> List[Record]:
         pass
