@@ -21,50 +21,50 @@ class MockSynapse(Synapse):
             supportedAuthTypes=[AuthMetadata(authType=AuthType.BASIC_TOKEN)],
             configuredFields=[AuthField(name='CRM ID')])
 
-    def describe(self):
-        self.__print(self.describe.__name__, self.request)
+    def describe(self, desc_request):
+        self.__print(self.describe.__name__, desc_request)
         schemas = []
         mock_attr = Attribute.parse_obj({'apiName':'MockAttr','displayName':'MockAttrDisplayName'})
         schemas.append(Schema.parse_obj({'apiName':'MockSchema','displayName':'MockDisplayName','attributes':[mock_attr]}))
         return schemas
 
-    def read(self):
-        self.__print(self.read.__name__, self.request)
-        watermark = self.request.watermark
+    def read(self, sync_request):
+        self.__print(self.read.__name__, sync_request)
+        watermark = sync_request.watermark
         eds = []
         eds.append(Record.parse_obj({'name':'MockRecord','values':{'key':'val'}}))
         return ReadResponse(watermark=watermark,data=eds)
 
-    def get_by_id(self):
-        self.__print(self.get_by_id.__name__, self.request)
+    def get_by_id(self, sync_request):
+        self.__print(self.get_by_id.__name__, sync_request)
         eds = []
         eds.append(Record.parse_obj({'name':'MockRecord','values':{'key':'val'}}))
         return eds
 
-    def create(self):
-        self.__print(self.create.__name__, self.request)
+    def create(self, sync_request):
+        self.__print(self.create.__name__, sync_request)
         results = []
         results.append(Result.parse_obj({'id':'MockID'}))
         return results
 
-    def update(self):
-        self.__print(self.update.__name__, self.request)
+    def update(self, sync_request):
+        self.__print(self.update.__name__, sync_request)
         results = []
         results.append(Result.parse_obj({'id':'MockID'}))
         return results
 
-    def delete(self):
-        self.__print(self.delete.__name__, self.request)
+    def delete(self, sync_request):
+        self.__print(self.delete.__name__, sync_request)
         results = []
         results.append(Result.parse_obj({'id':'MockID'}))
         return results
 
-    def extract_webhook_identifier(self):
-        self.__print(self.extract_webhook_identifier.__name__, self.request)
+    def extract_webhook_identifier(self, webhook_request):
+        self.__print(self.extract_webhook_identifier.__name__, webhook_request)
         return 'MockWebhookID'
 
-    def process_webhook(self):
-        self.__print(self.process_webhook.__name__, self.request)
+    def process_webhook(self, webhook_request):
+        self.__print(self.process_webhook.__name__, webhook_request)
         eds = []
         eds.append(Record.parse_obj({'name':'MockRecord','values':{'key':'val'}}))
         return eds
