@@ -11,45 +11,45 @@ class MockResponseValidationSynapse(Synapse):
         self.logger.info(request)
         print()
 
-    def test(self):
+    def test(self, connection):
         connections = []
-        connections.append(self.connection)
+        connections.append(connection)
         return connections
 
     def synapse_info(self):
         return []
 
-    def describe(self):
-        self.__print(self.describe.__name__, self.request)
+    def describe(self, desc_request):
+        self.__print(self.describe.__name__, desc_request)
         return Schema.parse_obj({'apiName':'MockSchema','displayName':'MockDisplayName'})
 
-    def read(self):
-        self.__print(self.read.__name__, self.request)
-        watermark = self.request.watermark
+    def read(self, sync_request):
+        self.__print(self.read.__name__, sync_request)
+        watermark = sync_request.watermark
         return Record.parse_obj({'name':'MockRecord','values':{'key':'val'}})
 
-    def get_by_id(self):
-        self.__print(self.get_by_id.__name__, self.request)
+    def get_by_id(self, sync_request):
+        self.__print(self.get_by_id.__name__, sync_request)
         return Record.parse_obj({'name':'MockRecord','values':{'key':'val'}})
 
-    def create(self):
-        self.__print(self.create.__name__, self.request)
+    def create(self, sync_request):
+        self.__print(self.create.__name__, sync_request)
         return Result.parse_obj({'id':'MockID'})
 
-    def update(self):
-        self.__print(self.update.__name__, self.request)
+    def update(self, sync_request):
+        self.__print(self.update.__name__, sync_request)
         return Result.parse_obj({'id':'MockID'})
 
-    def delete(self):
-        self.__print(self.delete.__name__, self.request)
+    def delete(self, sync_request):
+        self.__print(self.delete.__name__, sync_request)
         return Result.parse_obj({'id':'MockID'})
 
-    def extract_webhook_identifier(self):
-        self.__print(self.extract_webhook_identifier.__name__, self.request)
+    def extract_webhook_identifier(self, webhook_request):
+        self.__print(self.extract_webhook_identifier.__name__, webhook_request)
         return ['MockWebhookID']
 
-    def process_webhook(self):
-        self.__print(self.process_webhook.__name__, self.request)
+    def process_webhook(self, webhook_request):
+        self.__print(self.process_webhook.__name__, webhook_request)
         return Result.parse_obj({'id':'MockID'})
 
 def _execute(synapse_request):
